#
# spec file for package libqt5-qtstyleplugins
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _name   qtstyleplugins
%define base_name libqt5
%define qt_version 5.0.0
%bcond_without gtk2
Name:           libqt5-qtstyleplugins
Version:        5.0.0+git20170311
Release:        bp160.1.10
Summary:        Qt 5 Style Plugins
License:        LGPL-2.1-with-Qt-Company-Qt-exception-1.1 OR LGPL-3.0-only
URL:            https://qt.io/
Source:         %{_name}-opensource-src-%{version}.tar.xz
# PATCH-FIX-OPENSUSE qtstyleplugins-gtksettings.patch sor.alexei@meowr.ru -- Align Qt with GTK settings a bit better.
Patch0:         qtstyleplugins-gtksettings.patch
# PATCH-FIX-OPENSUSE qtstyleplugins-fix-deprecations.patch -- Fix various Qt deprecations.
Patch1:         qtstyleplugins-fix-deprecations.patch
BuildRequires:  fdupes
BuildRequires:  libQt5Core-private-headers-devel >= %{qt_version}
BuildRequires:  libQt5Gui-private-headers-devel >= %{qt_version}
BuildRequires:  libQt5Widgets-private-headers-devel >= %{qt_version}
BuildRequires:  libqt5-qtbase-devel >= %{qt_version}
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(libudev)
%requires_eq    libQt5Core5
%if %{with gtk2}
BuildRequires:  libQt5PlatformSupport-private-headers-devel >= %{qt_version}
BuildRequires:  pkgconfig(gtk+-2.0)
BuildRequires:  pkgconfig(x11)
%endif

%description
Qt is a set of libraries for developing applications.

This package contains additional style plugins.

%if %{with gtk2}
%package platformtheme-gtk2
Summary:        Qt 5 gtk2 plugin
%requires_eq    libQt5Gui5
Supplements:    (libQt5Gui5 and libgtk-2_0-0)

%description platformtheme-gtk2
Qt 5 plugin for better integration with gtk-based desktop enviroments.
%endif

%package devel
Summary:        Qt 5 Style Plugins Development Files
Requires:       %{name} = %{version}
%if %{with gtk2}
Requires:       %{name}-platformtheme-gtk2 = %{version}
%endif

%description devel
You need this package, if you want to compile programs with qtstyleplugins.

%prep
%autosetup -p1 -n %{_name}-opensource-src-%{version}

%build
%qmake5
%make_build

%install
%qmake5_install

find %{buildroot} -type f -name "*.la" -delete -print

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post platformtheme-gtk2 -p /sbin/ldconfig

%postun platformtheme-gtk2 -p /sbin/ldconfig

%files
%dir %{_libqt5_libdir}/qt5/plugins/styles/
%{_libqt5_libdir}/qt5/plugins/styles/*.so
%if %{with gtk2}
%exclude %{_libqt5_libdir}/qt5/plugins/styles/libqgtk2style.so
%endif

%if %{with gtk2}
%files platformtheme-gtk2
%dir %{_libqt5_libdir}/qt5/plugins/platformthemes/
%{_libqt5_libdir}/qt5/plugins/platformthemes/libqgtk2.so
%dir %{_libqt5_libdir}/qt5/plugins/styles/
%{_libqt5_libdir}/qt5/plugins/styles/libqgtk2style.so
%endif

%files devel
%{_libqt5_libdir}/cmake/Qt5Widgets/Qt5Widgets_*StylePlugin.cmake
%if %{with gtk2}
%{_libqt5_libdir}/cmake/Qt5Gui/Qt5Gui_*ThemePlugin.cmake
%endif

%changelog
* Mon Aug 22 2022 Fabian Vogt <fabian@ritter-vogt.de>
- Edit qtstyleplugins-fix-deprecations.patch to use the older more
  reliable method for progress bar orientation (boo#1202611)
* Sat Feb  6 2021 Alexei Sorokin <sor.alexei@meowr.ru>
- Add qtstyleplugins-gtksettings.patch: Align Qt with GTK settings
  a bit better.
- Add qtstyleplugins-fix-deprecations.patch: Fix various Qt deprecations.
- Remove fix-build-qt5.15.patch: merge into
  qtstyleplugins-fix-deprecations.patch (not distinct enough).
* Tue Jun  9 2020 Fabian Vogt <fabian@ritter-vogt.de>
- Amend patch to fix issues with platform themes providing an
  incompatible palette (boo#1172658):
  * fix-build-qt5.15.patch
* Thu Mar  5 2020 Fabian Vogt <fvogt@suse.com>
- Add patch to fix build against Qt 5.15:
  * fix-build-qt5.15.patch
* Tue Mar 13 2018 christophe@krop.fr
- Fix the license tag.
* Mon Dec 11 2017 christophe@krop.fr
- Update the license tag (boo#967696)
* Thu Apr 27 2017 sor.alexei@meowr.ru
- Update to version 5.0.0+git20170311 (changes since
  5.0.0+git20170119):
  * Plastique, Motif/CDE: Fix QSpinBox height in layout.
  * Fix Plastique, Cleanlooks and Motif animation timer.
* Tue Jan 24 2017 sor.alexei@meowr.ru
- Update to version 5.0.0+git20170119 (changes since
  5.0.0+git20161215):
  * Use Use QCommonStyle instead of QProxyStyle in QCleanlooksStyle
    and QPlastiqueStyle: this allows to use correct colour
    (non-white) for label text in a QComboBox. Also improves
    progress bar drawing - now looks like in Qt4, the progress bar
    content fills the entire groove vertically.
* Thu Dec 15 2016 sor.alexei@meowr.ru
- Update to version 5.0.0+git20161215 (changes since
  5.0.0+git20161024):
  * Remove obsolete and unused QBB10StylePlugin::keys().
  * Remove unused sync.profile.
  * Fix building with Qt 5.8+.
- Remove 58.diff: fixed upstream.
* Wed Dec 14 2016 hrvoje.senjan@gmail.com
- Bump to 5.7.1
  * For more details please see:
    https://blog.qt.io/blog/2016/12/14/qt-5-7-1-released/
    and https://www.qt.io/qt5-7/
* Mon Nov 28 2016 sor.alexei@meowr.ru
- Update to version 5.0.0+git20161024:
  * Set plugin class name for styles.
- Remove libqt5-qtstyleplugins-class-names.patch: fixed upstream.
* Mon Nov 28 2016 hrvoje.senjan@gmail.com
- Add 58.diff: private Qt platformsupport module got splited into
  many pieces in 5.8. Use the appropriate module with Qt >= 5.8
* Mon Oct 24 2016 sor.alexei@meowr.ru
- Update to version 5.0.0+git20161022 (changes since
  5.0.0+git20161005):
  * Remove usage of deprecated QStyleOption*V<N>.
  * Add Q_DECL_OVERRIDE.
  * Build the BB10 style only with Qt 5.7 or later.
- Remove the conflict with libqt5-qtbase-platformtheme-gtk3 in
  libqt5-qtstyleplugins-platformtheme-gtk2: it causes the gtk2
  platform theme to practically never get installed.
  The reason for the conflict in the first place is overrated
  anyway: in order to get a segfault, a user would have to manually
  make an envvar "QT_STYLE_OVERRIDE=gtk2" with also having Gtk3
  Platform Theme triggered ("QT_QPA_PLATFORMTHEME=gtk3").
* Sat Oct  8 2016 sor.alexei@meowr.ru
- Initial package.
